@@ -23,6 +23,7 @@ from __future__ import annotations
 
 import struct
 from abc import ABC, abstractmethod
+from datetime import date, datetime
 from decimal import ROUND_HALF_UP, Decimal
 from functools import singledispatchmethod
 from math import isnan
@@ -49,6 +50,8 @@ from pyiceberg.types import (
 )
 from pyiceberg.utils.datetime import (
     date_str_to_days,
+    date_to_days,
+    datetime_to_micros,
     micros_to_days,
     time_str_to_micros,
     timestamp_to_micros,
@@ -145,6 +148,10 @@ def literal(value: L) -> Literal[L]:
         return BinaryLiteral(value)
     elif isinstance(value, Decimal):
         return DecimalLiteral(value)
+    elif isinstance(value, datetime):
+        return TimestampLiteral(datetime_to_micros(value))  # type: ignore
+    elif isinstance(value, date):
+        return DateLiteral(date_to_days(value))  # type: ignore
     else:
         raise TypeError(f"Invalid literal value: {repr(value)}")
 
@@ -311,6 +318,10 @@ class LongLiteral(Literal[int]):
     def _(self, _: TimestampType) -> Literal[int]:
         return TimestampLiteral(self.value)
 
+    @to.register(TimestamptzType)
+    def _(self, _: TimestamptzType) -> Literal[int]:
+        return TimestampLiteral(self.value)
+
     @to.register(DecimalType)
     def _(self, type_var: DecimalType) -> Literal[Decimal]:
         unscaled = Decimal(self.value)
