@@ -21,24 +21,16 @@ from abc import ABC, abstractmethod
 from dataclasses import dataclass
 from datetime import date, datetime, time
 from functools import cached_property, singledispatch
-from typing import (
-    Any,
-    Dict,
-    Generic,
-    List,
-    Optional,
-    Tuple,
-    TypeVar,
-)
-from urllib.parse import quote
+from typing import Annotated, Any, Dict, Generic, List, Optional, Tuple, TypeVar, Union
+from urllib.parse import quote_plus
 
 from pydantic import (
     BeforeValidator,
     Field,
     PlainSerializer,
     WithJsonSchema,
+    model_validator,
 )
-from typing_extensions import Annotated
 
 from pyiceberg.schema import Schema
 from pyiceberg.transforms import (
@@ -111,6 +103,19 @@ class PartitionField(IcebergBaseModel):
 
         super().__init__(**data)
 
+    @model_validator(mode="before")
+    @classmethod
+    def map_source_ids_onto_source_id(cls, data: Any) -> Any:
+        if isinstance(data, dict):
+            if "source-id" not in data and (source_ids := data["source-ids"]):
+                if isinstance(source_ids, list):
+                    if len(source_ids) == 0:
+                        raise ValueError("Empty source-ids is not allowed")
+                    if len(source_ids) > 1:
+                        raise ValueError("Multi argument transforms are not yet supported")
+                    data["source-id"] = source_ids[0]
+        return data
+
     def __str__(self) -> str:
         """Return the string representation of the PartitionField class."""
         return f"{self.field_id}: {self.name}: {self.transform}({self.source_id})"
@@ -234,9 +239,8 @@ class PartitionSpec(IcebergBaseModel):
             partition_field = self.fields[pos]
             value_str = partition_field.transform.to_human_string(field_types[pos].field_type, value=data[pos])
 
-            value_str = quote(value_str, safe="")
-            value_strs.append(value_str)
-            field_strs.append(partition_field.name)
+            value_strs.append(quote_plus(value_str, safe=""))
+            field_strs.append(quote_plus(partition_field.name, safe=""))
 
         path = "/".join([field_str + "=" + value_str for field_str, value_str in zip(field_strs, value_strs)])
         return path
@@ -380,14 +384,14 @@ class PartitionFieldValue:
 
 @dataclass(frozen=True)
 class PartitionKey:
-    raw_partition_field_values: List[PartitionFieldValue]
+    field_values: List[PartitionFieldValue]
     partition_spec: PartitionSpec
     schema: Schema
 
     @cached_property
     def partition(self) -> Record:  # partition key transformed with iceberg internal representation as input
         iceberg_typed_key_values = {}
-        for raw_partition_field_value in self.raw_partition_field_values:
+        for raw_partition_field_value in self.field_values:
             partition_fields = self.partition_spec.source_id_to_fields_map[raw_partition_field_value.field.source_id]
             if len(partition_fields) != 1:
                 raise ValueError(f"Cannot have redundant partitions: {partition_fields}")
@@ -414,25 +418,45 @@ def partition_record_value(partition_field: PartitionField, value: Any, schema:
     the final partition record value.
     """
     iceberg_type = schema.find_field(name_or_id=partition_field.source_id).field_type
-    iceberg_typed_value = _to_partition_representation(iceberg_type, value)
-    transformed_value = partition_field.transform.transform(iceberg_type)(iceberg_typed_value)
-    return transformed_value
+    return _to_partition_representation(iceberg_type, value)
 
 
 @singledispatch
 def _to_partition_representation(type: IcebergType, value: Any) -> Any:
+    """Strip the logical type into the physical type.
+
+    It can be that the value is already transformed into its physical type,
+    in this case it will return the original value. Keep in mind that the
+    bucket transform always will return an int, but an identity transform
+    can return date that still needs to be transformed into an int (days
+    since epoch).
+    """
     return TypeError(f"Unsupported partition field type: {type}")
 
 
 @_to_partition_representation.register(TimestampType)
 @_to_partition_representation.register(TimestamptzType)
-def _(type: IcebergType, value: Optional[datetime]) -> Optional[int]:
-    return datetime_to_micros(value) if value is not None else None
+def _(type: IcebergType, value: Optional[Union[int, datetime]]) -> Optional[int]:
+    if value is None:
+        return None
+    elif isinstance(value, int):
+        return value
+    elif isinstance(value, datetime):
+        return datetime_to_micros(value)
+    else:
+        raise ValueError(f"Unknown type: {value}")
 
 
 @_to_partition_representation.register(DateType)
-def _(type: IcebergType, value: Optional[date]) -> Optional[int]:
-    return date_to_days(value) if value is not None else None
+def _(type: IcebergType, value: Optional[Union[int, date]]) -> Optional[int]:
+    if value is None:
+        return None
+    elif isinstance(value, int):
+        return value
+    elif isinstance(value, date):
+        return date_to_days(value)
+    else:
+        raise ValueError(f"Unknown type: {value}")
 
 
 @_to_partition_representation.register(TimeType)
