@@ -906,6 +906,14 @@ def test_uuid_to_binary() -> None:
     assert isinstance(binary_literal, BinaryLiteral)  # type: ignore
 
 
+def test_literal_from_datetime() -> None:
+    assert isinstance(literal(datetime.datetime.now()), TimestampLiteral)
+
+
+def test_literal_from_date() -> None:
+    assert isinstance(literal(datetime.date.today()), DateLiteral)
+
+
 #   __  __      ___
 #  |  \/  |_  _| _ \_  _
 #  | |\/| | || |  _/ || |
